@@ -3,4 +3,5 @@ from .funcs import *
 from .catalog import pack_dictionary, ui_locale_json
 
 
-# TODO! Not load compiled localisations from the build/l10n prior to build!
+def start() -> None:
+    pass
